/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.mockvehicledataservice;

import java.awt.Color;
import java.util.ArrayList;
import java.util.List;
import javax.swing.ImageIcon;
import nl.cloudfarming.client.fleet.machine.MachineDataService.Model;
import nl.cloudfarming.client.fleet.machine.MachineDataService.StepInfo;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.MachineProperty;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.VehicleDataService;
import org.openide.util.ImageUtilities;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
@ServiceProvider(service = VehicleDataService.class)
public class MockFendtDataService implements VehicleDataService {

    List<Model> models = new ArrayList<>();

    public MockFendtDataService() {
        String tractorType = "Tractor";
        String brand = "Fendt";

        Model model = new Model(tractorType, brand, "F100");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        model.putProperty(Machine.PROP_IMAGE, loadImage());
        models.add(model);

        model = new Model(tractorType, brand, "F200a");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F200b");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F300-1");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F300-2");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        StepInfo step3 = new StepInfo("Fendt step #3");
        step3.addProperty(new MachineProperty(Integer.class, "Integer property", 4));
        step3.addProperty(new MachineProperty(Boolean.class, "Boolean property", true));
        step3.addProperty(new MachineProperty(Color.class, "Color property", Color.GREEN));

        MachineProperty dropdownProp = new MachineProperty(String.class, "Dropdown property", "C");
        dropdownProp.setPossibleValues(new String[]{
                    "A",
                    "B",
                    "C",
                    "D"});
        step3.addProperty(dropdownProp);

        for (Model m : models) {
            m.addAdditionalStep(step3);
        }
    }

    @Override
    public List<Model> getModels() {
        return models;
    }
    
    private ImageIcon loadImage() {
        return ImageUtilities.loadImageIcon("nl/cloudfarming/client/mockvehicledataservice/fendt.jpg", true);
    }
}